@@ -1,6 +1,7 @@
 from selenium import webdriver
 from selenium.webdriver.support.wait import WebDriverWait
 from selenium.webdriver.common.by import By
+from selenium.webdriver.chrome.service import Service as ChromeService
 import os
 
 options = webdriver.ChromeOptions()
@@ -9,7 +10,8 @@ options.add_argument('--no-sandbox')
 options.add_argument('--headless')
 options.add_argument('--disable-gpu')
 options.add_argument('--disable-dev-shm-usage')
-driver = webdriver.Chrome(options=options)
+service = ChromeService(executable_path="/usr/bin/chromedriver")
+driver = webdriver.Chrome(options=options, service=service)
 
 print("Running tests")
 driver.get("http://localhost:8888/SpecRunner.html?random=false")
